@@ -30,6 +30,7 @@ pub struct DockerCommand {
     mapping_ports: Vec<Port>,
     mapping_volumes: Vec<Volume>,
     host_network: bool,
+    env_file: String,
     name: Option<String>,
     daemon: bool,
     tty: bool,
@@ -38,11 +39,16 @@ pub struct DockerCommand {
 }
 
 impl DockerCommand {
-    pub fn with_context(_context: &Context, docker_image: String, code_path: String) -> Self {
-        Self::with_config(docker_image, code_path)
+    pub fn with_context(
+        _context: &Context,
+        docker_image: String,
+        code_path: String,
+        env_file: String,
+    ) -> Self {
+        Self::with_config(docker_image, code_path, env_file)
     }
 
-    pub fn with_config(docker_image: String, code_path: String) -> Self {
+    pub fn with_config(docker_image: String, code_path: String, env_file: String) -> Self {
         let bin = DOCKER_BIN.to_string();
         let uid = users::get_current_uid();
         let gid = users::get_current_gid();
@@ -63,16 +69,17 @@ impl DockerCommand {
             mapping_ports: Vec::new(),
             mapping_volumes: Vec::new(),
             host_network: false,
+            env_file,
             name: None,
             daemon: false,
             tty: false,
             workdir: "/code".to_string(),
             inherited_env: vec![
-                "HTTP_PROXY",
-                "http_proxy",
-                "HTTPS_PROXY",
-                "https_proxy",
-                "ALL_PROXY",
+                //"HTTP_PROXY",
+                //"http_proxy",
+                //"HTTPS_PROXY",
+                //"https_proxy",
+                //"ALL_PROXY",
             ],
         }
     }
@@ -166,6 +173,7 @@ impl DockerCommand {
             mapping_ports,
             mut mapping_volumes,
             host_network,
+            env_file,
             name,
             daemon,
             tty,
@@ -215,6 +223,10 @@ impl DockerCommand {
             cmd.arg("--network").arg("host");
         }
 
+        if !env_file.is_empty() {
+            cmd.arg("--env-file").arg(env_file);
+        }
+
         if let Some(name) = name {
             cmd.arg("--name").arg(name);
         }
